@@ -47,6 +47,16 @@ class App:
             request_queue_size=500,
             server_name=socket.gethostname()
         )
+        
+        # dir_path = os.path.dirname(os.path.realpath(__file__))
+        # path = os.path.join(self.dir_path, "selfpages")
+        # dashboard_env = Environment(
+        #     loader=FileSystemLoader(os.path.join(self.dir_path, "selfpages")))
+        
+        # def default_app_dashboard(req, res):
+        #     res.body = dashboard_env.get_template("default-dashboard.html").render({"app_host": self.host, "app_port": self.port}).encode()
+        
+        # self.add_route("/default-app-dashboard", default_app_dashboard)
 
     def wsgi_app(self, environ, start_response):
         request = Request(environ)
@@ -152,6 +162,7 @@ class App:
 
     def register_collection(self, collection):
         assert collection not in self.collections, f"Collection {collection} already registered"
+        collection.set_wsgi(self.wsgi_app)
         for path in collection.routes.keys():
             assert path not in self.routes, f"Route {path} already exists"
 
